"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.open = open;
var _reactNative = require("react-native");
var _reactNativeUuid = _interopRequireDefault(require("react-native-uuid"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
// @ts-expect-error
const isTurboModuleEnabled = global.__turboModuleProxy != null;
const FileViewerTurbo = isTurboModuleEnabled ? require('./NativeFileViewerTurbo').default : _reactNative.NativeModules.FileViewerTurbo;
const eventEmitter = isTurboModuleEnabled ? null : new _reactNative.NativeEventEmitter(FileViewerTurbo);
async function open(path, options = {}) {
  const {
    onDismiss,
    ...nativeOptions
  } = options;
  try {
    const currentId = _reactNativeUuid.default.v4();
    await FileViewerTurbo.open(normalize(path), currentId, nativeOptions);
    if (_reactNative.Platform.OS !== 'ios') {
      return;
    }
    const dismissSubscription = addListener('onViewerDidDismiss', ({
      id
    }) => {
      if (id === currentId) {
        dismissSubscription?.remove();
        onDismiss && onDismiss();
      }
    });
  } catch (error) {
    throw error;
  }
}
const addListener = (event, listener) => {
  return isTurboModuleEnabled ? FileViewerTurbo[event](listener) : eventEmitter?.addListener(event, listener);
};
function normalize(path) {
  const filePrefix = 'file://';
  if (path.startsWith(filePrefix)) {
    path = path.substring(filePrefix.length);
    try {
      path = decodeURI(path);
    } catch (e) {}
  }
  return path;
}
//# sourceMappingURL=index.js.map